@@ -1,4 +1,5 @@
 # Copyright (C) 2016 Adrien Vergé
+# Copyright (C) 2023–2025 Jason Yundt
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,6 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import glob
 import locale
 import os
 import pty
@@ -20,9 +22,15 @@ import shutil
 import sys
 import tempfile
 import unittest
-from io import StringIO
 
-from tests.common import build_temp_workspace, RunContext, temp_workspace
+from tests.common import (
+    RunContext,
+    build_temp_workspace,
+    register_test_codecs,
+    temp_workspace,
+    temp_workspace_with_files_in_many_codecs,
+    unregister_test_codecs
+)
 
 from yamllint import cli, config
 
@@ -38,26 +46,6 @@ def utf8_available():
         return True
 
 
-def setUpModule():
-    # yamllint uses these environment variables to find a config file.
-    env_vars_that_could_interfere = (
-        'YAMLLINT_CONFIG_FILE',
-        'XDG_CONFIG_HOME',
-        # These variables are used to determine where the user’s home
-        # directory is. See
-        # https://docs.python.org/3/library/os.path.html#os.path.expanduser
-        'HOME',
-        'USERPROFILE',
-        'HOMEPATH',
-        'HOMEDRIVE'
-    )
-    for name in env_vars_that_could_interfere:
-        try:
-            del os.environ[name]
-        except KeyError:
-            pass
-
-
 class CommandLineTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
@@ -295,14 +283,14 @@ class CommandLineTestCase(unittest.TestCase):
             (ctx.returncode, ctx.stdout, ctx.stderr), (0, expected_out, ''))
 
     def test_run_with_config_file(self):
-        with open(os.path.join(self.wd, 'config'), 'w') as f:
+        with open(os.path.join(self.wd, 'config'), 'w', encoding='utf_8') as f:
             f.write('rules: {trailing-spaces: disable}')
 
         with RunContext(self) as ctx:
             cli.run(('-c', f.name, os.path.join(self.wd, 'a.yaml')))
         self.assertEqual(ctx.returncode, 0)
 
-        with open(os.path.join(self.wd, 'config'), 'w') as f:
+        with open(os.path.join(self.wd, 'config'), 'w', encoding='utf_8') as f:
             f.write('rules: {trailing-spaces: enable}')
 
         with RunContext(self) as ctx:
@@ -318,14 +306,14 @@ class CommandLineTestCase(unittest.TestCase):
         self.addCleanup(os.environ.__delitem__, 'HOME')
         os.environ['HOME'] = home
 
-        with open(config, 'w') as f:
+        with open(config, 'w', encoding='utf_8') as f:
             f.write('rules: {trailing-spaces: disable}')
 
         with RunContext(self) as ctx:
             cli.run((os.path.join(self.wd, 'a.yaml'), ))
         self.assertEqual(ctx.returncode, 0)
 
-        with open(config, 'w') as f:
+        with open(config, 'w', encoding='utf_8') as f:
             f.write('rules: {trailing-spaces: enable}')
 
         with RunContext(self) as ctx:
@@ -338,7 +326,8 @@ class CommandLineTestCase(unittest.TestCase):
         with tempfile.TemporaryDirectory('w') as d:
             os.environ['XDG_CONFIG_HOME'] = d
             os.makedirs(os.path.join(d, 'yamllint'))
-            with open(os.path.join(d, 'yamllint', 'config'), 'w') as f:
+            path = os.path.join(d, 'yamllint', 'config')
+            with open(path, 'w', encoding='utf_8') as f:
                 f.write('extends: relaxed')
             with RunContext(self) as ctx:
                 cli.run(('-f', 'parsable', os.path.join(self.wd, 'warn.yaml')))
@@ -348,7 +337,7 @@ class CommandLineTestCase(unittest.TestCase):
     def test_run_with_user_yamllint_config_file_in_env(self):
         self.addCleanup(os.environ.__delitem__, 'YAMLLINT_CONFIG_FILE')
 
-        with tempfile.NamedTemporaryFile('w') as f:
+        with tempfile.NamedTemporaryFile('w', encoding='utf_8') as f:
             os.environ['YAMLLINT_CONFIG_FILE'] = f.name
             f.write('rules: {trailing-spaces: disable}')
             f.flush()
@@ -356,7 +345,7 @@ class CommandLineTestCase(unittest.TestCase):
                 cli.run((os.path.join(self.wd, 'a.yaml'), ))
             self.assertEqual(ctx.returncode, 0)
 
-        with tempfile.NamedTemporaryFile('w') as f:
+        with tempfile.NamedTemporaryFile('w', encoding='utf_8') as f:
             os.environ['YAMLLINT_CONFIG_FILE'] = f.name
             f.write('rules: {trailing-spaces: enable}')
             f.flush()
@@ -498,8 +487,13 @@ class CommandLineTestCase(unittest.TestCase):
         path = os.path.join(self.wd, 'a.yaml')
 
         # Create a pseudo-TTY and redirect stdout to it
+        old_stdout = sys.stdout
         master, slave = pty.openpty()
-        sys.stdout = os.fdopen(slave, 'w')
+        sys.stdout = os.fdopen(
+            slave,
+            'w',
+            encoding=os.device_encoding(slave)
+        )
 
         with self.assertRaises(SystemExit) as ctx:
             cli.run((path, ))
@@ -508,13 +502,14 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(ctx.exception.code, 1)
 
         # Read output from TTY
-        output = os.fdopen(master, 'r')
+        output = os.fdopen(master, 'r', encoding=os.device_encoding(master))
         os.set_blocking(master, False)
 
         out = output.read().replace('\r\n', '\n')
 
         sys.stdout.close()
         output.close()
+        sys.stdout = old_stdout
 
         self.assertEqual(out, (
             f'\033[4m{path}\033[0m\n'
@@ -617,20 +612,32 @@ class CommandLineTestCase(unittest.TestCase):
             (ctx.returncode, ctx.stdout, ctx.stderr), (1, expected_out, ''))
 
     def test_run_read_from_stdin(self):
-        # prepares stdin with an invalid yaml string so that we can check
-        # for its specific error, and be assured that stdin was read
         self.addCleanup(setattr, sys, 'stdin', sys.__stdin__)
-        sys.stdin = StringIO(
-            'I am a string\n'
-            'therefore: I am an error\n')
+        # Normally, I would just use tempfile.TemporaryFile(), but here I want
+        # to first open the file for writing and then open it for reading. In
+        # other words, I need to make sure that the file continues to exist
+        # after I close it for the fist time. That’s why I’m using
+        # tempfile.TemporaryDirectory() instead of tempfile.TemporaryFile().
+        with tempfile.TemporaryDirectory() as temp_dir_path:
+            stdin_file_path = os.path.join(temp_dir_path, 'stdin')
+            with open(stdin_file_path, mode='w', encoding='utf_8') as file:
+                file.write(
+                    'I am a string\n'
+                    'therefore: I am an error\n')
+            with open(stdin_file_path, mode='r', encoding='utf-8') as file:
+                # prepares stdin with an invalid yaml string so that we can
+                # check for its specific error, and be assured that stdin was
+                # read
+                sys.stdin = file
 
-        with RunContext(self) as ctx:
-            cli.run(('-', '-f', 'parsable'))
-        expected_out = (
-            'stdin:2:10: [error] syntax error: '
-            'mapping values are not allowed here (syntax)\n')
-        self.assertEqual(
-            (ctx.returncode, ctx.stdout, ctx.stderr), (1, expected_out, ''))
+                with RunContext(self) as ctx:
+                    cli.run(('-', '-f', 'parsable'))
+                expected_out = (
+                    'stdin:2:10: [error] syntax error: '
+                    'mapping values are not allowed here (syntax)\n')
+                self.assertEqual(
+                    (ctx.returncode, ctx.stdout, ctx.stderr),
+                    (1, expected_out, ''))
 
     def test_run_no_warnings(self):
         path = os.path.join(self.wd, 'a.yaml')
@@ -814,3 +821,94 @@ class CommandLineConfigTestCase(unittest.TestCase):
         self.assertEqual((ctx.returncode, ctx.stdout, ctx.stderr),
                          (0, './4spaces.yml:2:5: [warning] wrong indentation: '
                          'expected 3 but found 4 (indentation)\n', ''))
+
+
+class CommandLineEncodingTestCase(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls):
+        super().setUpClass()
+        register_test_codecs()
+
+    @classmethod
+    def tearDownClass(cls):
+        super().tearDownClass()
+        unregister_test_codecs()
+
+    def valid_encodings_stdin_test_helper(
+        self,
+        config_path,
+        root_dir,
+        old_stdin
+    ):
+        for path in glob.glob(os.path.join(root_dir, '**')):
+            # We purposely choose the wrong text encoding here because the text
+            # encoding shouldn’t matter. yamllint should completely ignore the
+            # text encoding of stdin.
+            with open(path, mode="r", encoding="cp037") as file:
+                sys.stdin = file
+                with RunContext(self) as ctx:
+                    cli.run(('-c', config_path, '-'))
+                sys.stdin = old_stdin
+                if root_dir == 'sorted_correctly':
+                    self.assertEqual(ctx.returncode, 0)
+                elif root_dir == 'sorted_incorrectly':
+                    self.assertNotEqual(ctx.returncode, 0)
+                else:
+                    raise ValueError(
+                        f"root_dir was set to {repr(root_dir)}. It should only"
+                        "ever be set to 'sorted_correctly' or"
+                        "'sorted_incorrectly'."
+                    )
+
+    def test_valid_encodings(self):
+        old_stdin = sys.stdin
+        self.addCleanup(setattr, sys, 'stdin', old_stdin)
+        conf = ('---\n'
+                'rules:\n'
+                '  key-ordering: enable\n')
+        config_files = temp_workspace_with_files_in_many_codecs(
+            'config_{}.yaml',
+            conf
+        )
+        sorted_correctly = ('---\n'
+                            'Ａ: YAML\n'
+                            'Ｚ: YAML\n')
+        sorted_correctly_files = temp_workspace_with_files_in_many_codecs(
+            'sorted_correctly/{}.yaml',
+            sorted_correctly
+        )
+        sorted_incorrectly = ('---\n'
+                              'Ｚ: YAML\n'
+                              'Ａ: YAML\n')
+        sorted_incorrectly_files = temp_workspace_with_files_in_many_codecs(
+            'sorted_incorrectly/{}.yaml',
+            sorted_incorrectly
+        )
+        workspace = {
+            **config_files,
+            **sorted_correctly_files,
+            **sorted_incorrectly_files
+        }
+
+        with temp_workspace(workspace):
+            for config_path in config_files.keys():
+                # First, make sure that encoding autodetection works when the
+                # file’s path is given as a command-line argument.
+                with RunContext(self) as ctx:
+                    cli.run(('-c', config_path, 'sorted_correctly'))
+                self.assertEqual(ctx.returncode, 0)
+                with RunContext(self) as ctx:
+                    cli.run(('-c', config_path, 'sorted_incorrectly'))
+                self.assertNotEqual(ctx.returncode, 0)
+                # Second, make sure that encoding autodetection works when the
+                # file is piped to yamllint via stdin.
+                self.valid_encodings_stdin_test_helper(
+                    config_path,
+                    'sorted_correctly',
+                    old_stdin
+                )
+                self.valid_encodings_stdin_test_helper(
+                    config_path,
+                    'sorted_incorrectly',
+                    old_stdin
+                )
