@@ -197,6 +197,10 @@ class SimpleConfigTestCase(unittest.TestCase):
                           {'multiple': ['item4']})
 
     def test_invalid_rule(self):
+        with self.assertRaisesRegex(
+                config.YamlLintConfigError,
+                'invalid config: rules should be a dict'):
+            config.YamlLintConfig('rules:\n')
         with self.assertRaisesRegex(
                 config.YamlLintConfigError,
                 'invalid config: rule "colons": should be either '
